pb

package
v0.0.0-...-4d6262f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 7, 2023 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	VideoOutputFormat_name = map[int32]string{
		0: "MPEG_DASH",
		1: "HLS",
	}
	VideoOutputFormat_value = map[string]int32{
		"MPEG_DASH": 0,
		"HLS":       1,
	}
)

Enum value maps for VideoOutputFormat.

var (
	VideoResolution_name = map[int32]string{
		0: "P144",
		1: "P240",
		2: "P360",
		3: "P480",
		4: "P720",
		5: "P1080",
		6: "P1440",
		7: "P2160",
	}
	VideoResolution_value = map[string]int32{
		"P144":  0,
		"P240":  1,
		"P360":  2,
		"P480":  3,
		"P720":  4,
		"P1080": 5,
		"P1440": 6,
		"P2160": 7,
	}
)

Enum value maps for VideoResolution.

var File_JobService_proto protoreflect.FileDescriptor
var File_common_proto protoreflect.FileDescriptor
var JobService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "jobs.JobService",
	HandlerType: (*JobServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "QueueJob",
			Handler:    _JobService_QueueJob_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "JobService.proto",
}

JobService_ServiceDesc is the grpc.ServiceDesc for JobService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterJobServiceServer

func RegisterJobServiceServer(s grpc.ServiceRegistrar, srv JobServiceServer)

Types

type JobRequest

type JobRequest struct {
	SrcPath         string            `protobuf:"bytes,1,opt,name=src_path,json=srcPath,proto3" json:"src_path,omitempty"`    // s3 path to the video
	DestPath        string            `protobuf:"bytes,2,opt,name=dest_path,json=destPath,proto3" json:"dest_path,omitempty"` // unqiue s3 path to directory
	OutFormat       VideoOutputFormat `protobuf:"varint,3,opt,name=out_format,json=outFormat,proto3,enum=common.VideoOutputFormat" json:"out_format,omitempty"`
	ConvResolutions []VideoResolution `` /* 142-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*JobRequest) Descriptor deprecated

func (*JobRequest) Descriptor() ([]byte, []int)

Deprecated: Use JobRequest.ProtoReflect.Descriptor instead.

func (*JobRequest) GetConvResolutions

func (x *JobRequest) GetConvResolutions() []VideoResolution

func (*JobRequest) GetDestPath

func (x *JobRequest) GetDestPath() string

func (*JobRequest) GetOutFormat

func (x *JobRequest) GetOutFormat() VideoOutputFormat

func (*JobRequest) GetSrcPath

func (x *JobRequest) GetSrcPath() string

func (*JobRequest) ProtoMessage

func (*JobRequest) ProtoMessage()

func (*JobRequest) ProtoReflect

func (x *JobRequest) ProtoReflect() protoreflect.Message

func (*JobRequest) Reset

func (x *JobRequest) Reset()

func (*JobRequest) String

func (x *JobRequest) String() string

type JobResponse

type JobResponse struct {
	Status int32 `protobuf:"varint,1,opt,name=status,proto3" json:"status,omitempty"`
	// contains filtered or unexported fields
}

func (*JobResponse) Descriptor deprecated

func (*JobResponse) Descriptor() ([]byte, []int)

Deprecated: Use JobResponse.ProtoReflect.Descriptor instead.

func (*JobResponse) GetStatus

func (x *JobResponse) GetStatus() int32

func (*JobResponse) ProtoMessage

func (*JobResponse) ProtoMessage()

func (*JobResponse) ProtoReflect

func (x *JobResponse) ProtoReflect() protoreflect.Message

func (*JobResponse) Reset

func (x *JobResponse) Reset()

func (*JobResponse) String

func (x *JobResponse) String() string

type JobServiceClient

type JobServiceClient interface {
	QueueJob(ctx context.Context, in *JobRequest, opts ...grpc.CallOption) (*JobResponse, error)
}

JobServiceClient is the client API for JobService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewJobServiceClient

func NewJobServiceClient(cc grpc.ClientConnInterface) JobServiceClient

type JobServiceServer

type JobServiceServer interface {
	QueueJob(context.Context, *JobRequest) (*JobResponse, error)
	// contains filtered or unexported methods
}

JobServiceServer is the server API for JobService service. All implementations must embed UnimplementedJobServiceServer for forward compatibility

type UnimplementedJobServiceServer

type UnimplementedJobServiceServer struct {
}

UnimplementedJobServiceServer must be embedded to have forward compatible implementations.

func (UnimplementedJobServiceServer) QueueJob

type UnsafeJobServiceServer

type UnsafeJobServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeJobServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to JobServiceServer will result in compilation errors.

type VideoOutputFormat

type VideoOutputFormat int32
const (
	VideoOutputFormat_MPEG_DASH VideoOutputFormat = 0
	VideoOutputFormat_HLS       VideoOutputFormat = 1
)

func (VideoOutputFormat) Descriptor

func (VideoOutputFormat) Enum

func (VideoOutputFormat) EnumDescriptor deprecated

func (VideoOutputFormat) EnumDescriptor() ([]byte, []int)

Deprecated: Use VideoOutputFormat.Descriptor instead.

func (VideoOutputFormat) Number

func (VideoOutputFormat) String

func (x VideoOutputFormat) String() string

func (VideoOutputFormat) Type

type VideoResolution

type VideoResolution int32
const (
	VideoResolution_P144  VideoResolution = 0
	VideoResolution_P240  VideoResolution = 1
	VideoResolution_P360  VideoResolution = 2
	VideoResolution_P480  VideoResolution = 3
	VideoResolution_P720  VideoResolution = 4
	VideoResolution_P1080 VideoResolution = 5 // HD
	VideoResolution_P1440 VideoResolution = 6 // Ultra HD
	VideoResolution_P2160 VideoResolution = 7 // 4k
)

func (VideoResolution) Descriptor

func (VideoResolution) Enum

func (x VideoResolution) Enum() *VideoResolution

func (VideoResolution) EnumDescriptor deprecated

func (VideoResolution) EnumDescriptor() ([]byte, []int)

Deprecated: Use VideoResolution.Descriptor instead.

func (VideoResolution) Number

func (VideoResolution) String

func (x VideoResolution) String() string

func (VideoResolution) Type

Jump to